aboutsummaryrefslogtreecommitdiff
path: root/engine/lib/access.php
diff options
context:
space:
mode:
Diffstat (limited to 'engine/lib/access.php')
-rw-r--r--engine/lib/access.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/lib/access.php b/engine/lib/access.php
index b87d150c0..ef9794802 100644
--- a/engine/lib/access.php
+++ b/engine/lib/access.php
@@ -725,7 +725,7 @@ function get_members_of_access_collection($collection, $idonly = FALSE) {
}
/**
* Displays a user's access collections, using the friends/collections view
*
* @param int $owner_guid The GUID of the owning user
*
@@ -740,7 +740,7 @@ function elgg_view_access_collections($owner_guid) {
}
}
- return elgg_view('friends/collections', array('collections' => $collections));
+ return elgg_view('core/friends/collections', array('collections' => $collections));
}
/**
@@ -725,7 +725,7 @@ function get_members_of_access_collection($collection, $idonly = FALSE) {
}
/**
- * Displays a user's access collections, using the friends/collections view
+ * Displays a user's access collections, using the core/friends/collections view
*
* @param int $owner_guid The GUID of the owning user